Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/GuardLabel.java')
-rw-r--r--extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/GuardLabel.java35
1 files changed, 18 insertions, 17 deletions
diff --git a/extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/GuardLabel.java b/extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/GuardLabel.java
index f08635f6e46..4bd5b4c94a0 100644
--- a/extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/GuardLabel.java
+++ b/extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/GuardLabel.java
@@ -11,7 +11,6 @@
*/
package org.eclipse.papyrus.umldi;
-
/**
* <!-- begin-user-doc -->
* A representation of the model object '<em><b>Guard Label</b></em>'.
@@ -21,7 +20,7 @@ package org.eclipse.papyrus.umldi;
* The following features are supported:
* </p>
* <ul>
- * <li>{@link org.eclipse.papyrus.umldi.GuardLabel#getRelationshipWithGuardEdge <em>Relationship With Guard Edge</em>}</li>
+ * <li>{@link org.eclipse.papyrus.umldi.GuardLabel#getActivityEdgeEdge <em>Activity Edge Edge</em>}</li>
* </ul>
*
* @see org.eclipse.papyrus.umldi.UMLDIPackage#getGuardLabel()
@@ -29,38 +28,40 @@ package org.eclipse.papyrus.umldi;
* @generated
*/
public interface GuardLabel extends UmlLabel {
+
/**
* Returns the value of the '<em><b>Relationship With Guard Edge</b></em>' container reference.
* It is bidirectional and its opposite is '{@link org.eclipse.papyrus.umldi.RelationshipWithGuardEdge#getGuardLabel <em>Guard Label</em>}'.
* <p>
* This feature subsets the following features:
* </p>
* <ul>
- * <li>'{@link org.eclipse.papyrus.umldi.UmlDiagramElement#getOwningUmlDiagramElement() <em>Owning Uml Diagram Element</em>}'</li>
+ * <li>'{@link org.eclipse.papyrus.umldi.UmlDiagramElement#getOwningUmlDiagramElement() <em>Owning Uml Diagram Element</em>}'</li>
* </ul>
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Relationship With Guard Edge</em>' container reference isn't clear,
* there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Relationship With Guard Edge</em>' container reference.
* @see #setRelationshipWithGuardEdge(RelationshipWithGuardEdge)
* @see org.eclipse.papyrus.umldi.UMLDIPackage#getGuardLabel_RelationshipWithGuardEdge()
* @see org.eclipse.papyrus.umldi.RelationshipWithGuardEdge#getGuardLabel
* @model opposite="guardLabel" transient="false" ordered="false"
* @generated
*/
- RelationshipWithGuardEdge getRelationshipWithGuardEdge();
+ ActivityEdgeEdge getActivityEdgeEdge();
/**
* Sets the value of the '{@link org.eclipse.papyrus.umldi.GuardLabel#getRelationshipWithGuardEdge <em>Relationship With Guard Edge</em>}' container reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Relationship With Guard Edge</em>' container reference.
* @see #getRelationshipWithGuardEdge()
* @generated
*/
- void setRelationshipWithGuardEdge(RelationshipWithGuardEdge value);
-
+ void setActivityEdgeEdge(ActivityEdgeEdge value);
} // GuardLabel

Back to the top
@@ -29,38 +28,40 @@ package org.eclipse.papyrus.umldi;
/**
- * Returns the value of the '<em><b>Relationship With Guard Edge</b></em>' container reference.
- * It is bidirectional and its opposite is '{@link org.eclipse.papyrus.umldi.RelationshipWithGuardEdge#getGuardLabel <em>Guard Label</em>}'.
+ * Returns the value of the '<em><b>Activity Edge Edge</b></em>' container reference.
+ * It is bidirectional and its opposite is '{@link org.eclipse.papyrus.umldi.ActivityEdgeEdge#getGuardLabel <em>Guard Label</em>}'.
* <p>
* This feature subsets the following features:
@@ -29,38 +28,40 @@ package org.eclipse.papyrus.umldi;
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Relationship With Guard Edge</em>' container reference isn't clear,
- * there really should be more of a description here...
+ * If the meaning of the '<em>Activity Edge Edge</em>' container reference isn't clear, there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
@@ -29,38 +28,40 @@ package org.eclipse.papyrus.umldi;
* </p>
* <!-- end-user-doc -->
- * @return the value of the '<em>Relationship With Guard Edge</em>' container reference.
- * @see #setRelationshipWithGuardEdge(RelationshipWithGuardEdge)
- * @see org.eclipse.papyrus.umldi.UMLDIPackage#getGuardLabel_RelationshipWithGuardEdge()
- * @see org.eclipse.papyrus.umldi.RelationshipWithGuardEdge#getGuardLabel
+ *
+ * @return the value of the '<em>Activity Edge Edge</em>' container reference.
+ * @see #setActivityEdgeEdge(ActivityEdgeEdge)
+ * @see org.eclipse.papyrus.umldi.UMLDIPackage#getGuardLabel_ActivityEdgeEdge()
+ * @see org.eclipse.papyrus.umldi.ActivityEdgeEdge#getGuardLabel
* @model opposite="guardLabel" transient="false" ordered="false"
* @generated
@@ -29,38 +28,40 @@ package org.eclipse.papyrus.umldi;
/**
- * Sets the value of the '{@link org.eclipse.papyrus.umldi.GuardLabel#getRelationshipWithGuardEdge <em>Relationship With Guard Edge</em>}' container reference.
+ * Sets the value of the '{@link org.eclipse.papyrus.umldi.GuardLabel#getActivityEdgeEdge <em>Activity Edge Edge</em>}' container reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -29,38 +28,40 @@ package org.eclipse.papyrus.umldi;
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @param value the new value of the '<em>Relationship With Guard Edge</em>' container reference.
- * @see #getRelationshipWithGuardEdge()
+ *
+ * @param value
+ * the new value of the '<em>Activity Edge Edge</em>' container reference.
+ * @see #getActivityEdgeEdge()
* @generated
*/